@@ -1,10 +1,8 @@
 #include "levelgraph.hpp"
-#include <taskflow/taskflow.hpp> 
+#include <taskflow/taskflow.hpp>
 #include <taskflow/algorithm/pipeline.hpp>
 //#include "matrix_calculation.hpp"
 
-
-
 struct Input {
   size_t lev;
   size_t len;
@@ -13,13 +11,13 @@ struct Input {
 
   void operator()(tf::Pipeflow& pf) {
     if (len == 0 && lev == graph.level()) {
-      pf.stop(); 
+      pf.stop();
     }
     else {
       mybuffer[pf.line()] = graph.node_at(lev, len).uid();
       int val = work(mybuffer[pf.line()]);
       graph.node_at(lev, len).set_value(val);
-       
+
       if(len == graph.length()-1){
         ++lev;
         len = 0;
@@ -34,7 +32,7 @@ struct Input {
 struct Filter {
   std::vector<int>& mybuffer;
   LevelGraph& graph;
-  
+
   void operator()(tf::Pipeflow& pf) {
 
     int uid = mybuffer[pf.line()];
@@ -49,7 +47,7 @@ struct Filter {
 struct FilterFinal {
   std::vector<int>& mybuffer;
   LevelGraph& graph;
-   
+
   void operator()(tf::Pipeflow& pf){
     int uid = mybuffer[pf.line()];
     int val = work(uid);
@@ -68,11 +66,6 @@ struct FilterFinal {
     else {
       graph.node_at(lev, len).set_value(val);
     }
-
-    //std::ofstream outputfile;
-    //outputfile.open("./tf_result_.txt", std::ofstream::app);
-    //outputfile << graph.node_at(lev, len).get_value() << '\n';
-    //outputfile.close();
   }
 };
 
@@ -81,17 +74,17 @@ std::chrono::microseconds graph_pipeline_taskflow_1_pipe(
   LevelGraph& graph, unsigned num_lines, unsigned num_threads) {
 
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   std::vector<int> mybuffer(num_lines);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
     tf::Pipe{tf::PipeType::SERIAL, Input{0, 0, mybuffer, graph}} // 1st pipe
-  ); 
+  );
 
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
 
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
@@ -100,9 +93,9 @@ std::chrono::microseconds graph_pipeline_taskflow_1_pipe(
 // graph_pipeline_taskflow_2_pipes
 std::chrono::microseconds graph_pipeline_taskflow_2_pipes(
   LevelGraph& graph, unsigned num_lines, unsigned num_threads) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   std::vector<int> mybuffer(num_lines);
 
@@ -110,10 +103,10 @@ std::chrono::microseconds graph_pipeline_taskflow_2_pipes(
   tf::Pipeline pl(num_lines,
     tf::Pipe{tf::PipeType::SERIAL, Input{0, 0, mybuffer, graph}}, // 1st pipe
     tf::Pipe{tf::PipeType::SERIAL, FilterFinal{mybuffer, graph}}  // 2nd pipe
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -121,21 +114,21 @@ std::chrono::microseconds graph_pipeline_taskflow_2_pipes(
 // graph_pipeline_taskflow_3_pipes
 std::chrono::microseconds graph_pipeline_taskflow_3_pipes(
   LevelGraph& graph, unsigned num_lines, unsigned num_threads) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   std::vector<int> mybuffer(num_lines);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
     tf::Pipe{tf::PipeType::SERIAL, Input{0, 0, mybuffer, graph}}, // 1st pipe
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe 
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe
     tf::Pipe{tf::PipeType::SERIAL, FilterFinal{mybuffer, graph}}  // 3rd pipe
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -143,22 +136,22 @@ std::chrono::microseconds graph_pipeline_taskflow_3_pipes(
 // graph_pipeline_taskflow_4_pipes
 std::chrono::microseconds graph_pipeline_taskflow_4_pipes(
   LevelGraph& graph, unsigned num_lines, unsigned num_threads) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   std::vector<int> mybuffer(num_lines);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
     tf::Pipe{tf::PipeType::SERIAL, Input{0, 0, mybuffer, graph}}, // 1st pipe
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe 
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe
     tf::Pipe{tf::PipeType::SERIAL, FilterFinal{mybuffer, graph}}  // 4th pipe
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -166,23 +159,23 @@ std::chrono::microseconds graph_pipeline_taskflow_4_pipes(
 // graph_pipeline_taskflow_5_pipes
 std::chrono::microseconds graph_pipeline_taskflow_5_pipes(
   LevelGraph& graph, unsigned num_lines, unsigned num_threads) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   std::vector<int> mybuffer(num_lines);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
     tf::Pipe{tf::PipeType::SERIAL, Input{0, 0, mybuffer, graph}}, // 1st pipe
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe 
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe
     tf::Pipe{tf::PipeType::SERIAL, FilterFinal{mybuffer, graph}}  // 5th pipe
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -192,22 +185,22 @@ std::chrono::microseconds graph_pipeline_taskflow_6_pipes(
   LevelGraph& graph, unsigned num_lines, unsigned num_threads) {
 
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   std::vector<int> mybuffer(num_lines);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
     tf::Pipe{tf::PipeType::SERIAL, Input{0, 0, mybuffer, graph}}, // 1st pipe
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 5th pipe 
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 5th pipe
     tf::Pipe{tf::PipeType::SERIAL, FilterFinal{mybuffer, graph}}  // 6th pipe
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -217,23 +210,23 @@ std::chrono::microseconds graph_pipeline_taskflow_7_pipes(
   LevelGraph& graph, unsigned num_lines, unsigned num_threads) {
 
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   std::vector<int> mybuffer(num_lines);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
     tf::Pipe{tf::PipeType::SERIAL, Input{0, 0, mybuffer, graph}}, // 1st pipe
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 5th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 6th pipe 
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 5th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 6th pipe
     tf::Pipe{tf::PipeType::SERIAL, FilterFinal{mybuffer, graph}}  // 7th pipe
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -243,26 +236,26 @@ std::chrono::microseconds graph_pipeline_taskflow_8_pipes(
   LevelGraph& graph, unsigned num_lines, unsigned num_threads) {
   //std::ofstream outputfile;
   //outputfile.open("./tf_result.txt", std::ofstream::app);
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   std::vector<int> mybuffer(num_lines);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
     tf::Pipe{tf::PipeType::SERIAL, Input{0, 0, mybuffer, graph}}, // 1st pipe
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 5th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 6th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 7th pipe 
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 5th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 6th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 7th pipe
     tf::Pipe{tf::PipeType::SERIAL, FilterFinal{mybuffer, graph}}  // 8th pipe
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   //for(auto r:result) {
   //  outputfile << r << '\n';
@@ -273,27 +266,27 @@ std::chrono::microseconds graph_pipeline_taskflow_8_pipes(
 // graph_pipeline_taskflow_9_pipes
 std::chrono::microseconds graph_pipeline_taskflow_9_pipes(
   LevelGraph& graph, unsigned num_lines, unsigned num_threads) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   std::vector<int> mybuffer(num_lines);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
     tf::Pipe{tf::PipeType::SERIAL, Input{0, 0, mybuffer, graph}}, // 1st pipe
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 5th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 6th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 7th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 8th pipe 
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 5th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 6th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 7th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 8th pipe
     tf::Pipe{tf::PipeType::SERIAL, FilterFinal{mybuffer, graph}}  // 9th pipe
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -301,28 +294,28 @@ std::chrono::microseconds graph_pipeline_taskflow_9_pipes(
 // graph_pipeline_taskflow_10_pipes
 std::chrono::microseconds graph_pipeline_taskflow_10_pipes(
   LevelGraph& graph, unsigned num_lines, unsigned num_threads) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   std::vector<int> mybuffer(num_lines);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
     tf::Pipe{tf::PipeType::SERIAL, Input{0, 0, mybuffer, graph}}, // 1st pipe
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 5th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 6th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 7th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 8th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 9th pipe 
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 5th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 6th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 7th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 8th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 9th pipe
     tf::Pipe{tf::PipeType::SERIAL, FilterFinal{mybuffer, graph}}  // 10th pipe
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -331,29 +324,29 @@ std::chrono::microseconds graph_pipeline_taskflow_10_pipes(
 // graph_pipeline_taskflow_11_pipes
 std::chrono::microseconds graph_pipeline_taskflow_11_pipes(
   LevelGraph& graph, unsigned num_lines, unsigned num_threads) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   std::vector<int> mybuffer(num_lines);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
     tf::Pipe{tf::PipeType::SERIAL, Input{0, 0, mybuffer, graph}}, // 1st pipe
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 5th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 6th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 7th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 8th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 9th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 10th pipe 
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 5th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 6th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 7th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 8th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 9th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 10th pipe
     tf::Pipe{tf::PipeType::SERIAL, FilterFinal{mybuffer, graph}}  // 11th pipe
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -361,30 +354,30 @@ std::chrono::microseconds graph_pipeline_taskflow_11_pipes(
 // graph_pipeline_taskflow_12_pipes
 std::chrono::microseconds graph_pipeline_taskflow_12_pipes(
   LevelGraph& graph, unsigned num_lines, unsigned num_threads) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   std::vector<int> mybuffer(num_lines);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
     tf::Pipe{tf::PipeType::SERIAL, Input{0, 0, mybuffer, graph}}, // 1st pipe
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 5th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 6th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 7th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 8th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 9th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 10th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 11th pipe 
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 5th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 6th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 7th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 8th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 9th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 10th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 11th pipe
     tf::Pipe{tf::PipeType::SERIAL, FilterFinal{mybuffer, graph}}  // 12th pipe
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -392,31 +385,31 @@ std::chrono::microseconds graph_pipeline_taskflow_12_pipes(
 // graph_pipeline_taskflow_13_pipes
 std::chrono::microseconds graph_pipeline_taskflow_13_pipes(
   LevelGraph& graph, unsigned num_lines, unsigned num_threads) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   std::vector<int> mybuffer(num_lines);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
     tf::Pipe{tf::PipeType::SERIAL, Input{0, 0, mybuffer, graph}}, // 1st pipe
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 5th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 6th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 7th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 8th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 9th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 10th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 11th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 12th pipe 
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 5th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 6th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 7th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 8th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 9th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 10th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 11th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 12th pipe
     tf::Pipe{tf::PipeType::SERIAL, FilterFinal{mybuffer, graph}}  // 13th pipe
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -424,32 +417,32 @@ std::chrono::microseconds graph_pipeline_taskflow_13_pipes(
 // graph_pipeline_taskflow_14_pipes
 std::chrono::microseconds graph_pipeline_taskflow_14_pipes(
   LevelGraph& graph, unsigned num_lines, unsigned num_threads) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   std::vector<int> mybuffer(num_lines);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
     tf::Pipe{tf::PipeType::SERIAL, Input{0, 0, mybuffer, graph}}, // 1st pipe
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 5th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 6th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 7th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 8th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 9th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 10th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 11th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 12th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 13th pipe 
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 5th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 6th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 7th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 8th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 9th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 10th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 11th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 12th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 13th pipe
     tf::Pipe{tf::PipeType::SERIAL, FilterFinal{mybuffer, graph}}  // 14th pipe
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -457,33 +450,33 @@ std::chrono::microseconds graph_pipeline_taskflow_14_pipes(
 // graph_pipeline_taskflow_15_pipes
 std::chrono::microseconds graph_pipeline_taskflow_15_pipes(
   LevelGraph& graph, unsigned num_lines, unsigned num_threads) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   std::vector<int> mybuffer(num_lines);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
     tf::Pipe{tf::PipeType::SERIAL, Input{0, 0, mybuffer, graph}}, // 1st pipe
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 5th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 6th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 7th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 8th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 9th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 10th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 11th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 12th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 13th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 14th pipe 
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 5th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 6th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 7th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 8th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 9th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 10th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 11th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 12th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 13th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 14th pipe
     tf::Pipe{tf::PipeType::SERIAL, FilterFinal{mybuffer, graph}}  // 15th pipe
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -491,53 +484,53 @@ std::chrono::microseconds graph_pipeline_taskflow_15_pipes(
 // graph_pipeline_taskflow_16_pipes
 std::chrono::microseconds graph_pipeline_taskflow_16_pipes(
   LevelGraph& graph, unsigned num_lines, unsigned num_threads) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   std::vector<int> mybuffer(num_lines);
-   
+
   //std::ofstream outputfile;
   //outputfile.open("./tf_16_pipes.txt", std::ofstream::app);
-  
+
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
     tf::Pipe{tf::PipeType::SERIAL, Input{0, 0, mybuffer, graph}}, // 1st pipe
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 5th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 6th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 7th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 8th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 9th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 10th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 11th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 12th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 13th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 14th pipe 
-    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 15th pipe 
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 2nd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 3rd pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 4th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 5th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 6th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 7th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 8th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 9th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 10th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 11th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 12th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 13th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 14th pipe
+    tf::Pipe{tf::PipeType::SERIAL, Filter{mybuffer, graph}},      // 15th pipe
     tf::Pipe{tf::PipeType::SERIAL, FilterFinal{mybuffer, graph}}  // 16th pipe
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   //outputfile.close();
-  
+
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
 
 std::chrono::microseconds measure_time_taskflow(
   LevelGraph& graph, size_t pipes, unsigned num_lines, unsigned num_threads) {
- 
-  std::chrono::microseconds elapsed; 
-  
+
+  std::chrono::microseconds elapsed;
+
   switch(pipes) {
     case 1:
       elapsed = graph_pipeline_taskflow_1_pipe(graph, num_lines, num_threads);
     break;
-    
+
     case 2:
       elapsed = graph_pipeline_taskflow_2_pipes(graph, num_lines, num_threads);
     break;
@@ -545,7 +538,7 @@ std::chrono::microseconds measure_time_taskflow(
     case 3:
       elapsed = graph_pipeline_taskflow_3_pipes(graph, num_lines, num_threads);
     break;
-    
+
     case 4:
       elapsed = graph_pipeline_taskflow_4_pipes(graph, num_lines, num_threads);
     break;
@@ -553,11 +546,11 @@ std::chrono::microseconds measure_time_taskflow(
     case 5:
       elapsed = graph_pipeline_taskflow_5_pipes(graph, num_lines, num_threads);
     break;
-    
+
     case 6:
       elapsed = graph_pipeline_taskflow_6_pipes(graph, num_lines, num_threads);
     break;
-    
+
     case 7:
       elapsed = graph_pipeline_taskflow_7_pipes(graph, num_lines, num_threads);
     break;
@@ -565,7 +558,7 @@ std::chrono::microseconds measure_time_taskflow(
     case 8:
       elapsed = graph_pipeline_taskflow_8_pipes(graph, num_lines, num_threads);
     break;
-    
+
     case 9:
       elapsed = graph_pipeline_taskflow_9_pipes(graph, num_lines, num_threads);
     break;
@@ -573,11 +566,11 @@ std::chrono::microseconds measure_time_taskflow(
     case 10:
       elapsed = graph_pipeline_taskflow_10_pipes(graph, num_lines, num_threads);
     break;
-    
+
     case 11:
       elapsed = graph_pipeline_taskflow_11_pipes(graph, num_lines, num_threads);
     break;
-    
+
     case 12:
       elapsed = graph_pipeline_taskflow_12_pipes(graph, num_lines, num_threads);
     break;
@@ -585,7 +578,7 @@ std::chrono::microseconds measure_time_taskflow(
     case 13:
       elapsed = graph_pipeline_taskflow_13_pipes(graph, num_lines, num_threads);
     break;
-    
+
     case 14:
       elapsed = graph_pipeline_taskflow_14_pipes(graph, num_lines, num_threads);
     break;
@@ -593,21 +586,15 @@ std::chrono::microseconds measure_time_taskflow(
     case 15:
       elapsed = graph_pipeline_taskflow_15_pipes(graph, num_lines, num_threads);
     break;
-    
+
     case 16:
       elapsed = graph_pipeline_taskflow_16_pipes(graph, num_lines, num_threads);
     break;
+
+    default:
+      throw std::runtime_error("can support only up to 16 pipes");
+    break;
   }
-
-  //std::ofstream outputfile;
-  //outputfile.open("./tf_time.csv", std::ofstream::app);
-  //outputfile << num_threads               << ','
-  //           << num_lines                 << ','
-  //           << pipes                     << ','
-  //           << graph.graph_size()        << ','
-  //           << elapsed.count()/1e3 << '\n';
-
-  //outputfile.close();
   return elapsed;
 }
 
