@@ -1,5 +1,5 @@
 #include "linear_pipeline.hpp"
-#include <taskflow/taskflow.hpp> 
+#include <taskflow/taskflow.hpp>
 #include <taskflow/algorithm/pipeline.hpp>
 
 struct Input {
@@ -8,7 +8,7 @@ struct Input {
   void operator()(tf::Pipeflow& pf) {
     work();
     if (i++ == size) {
-      pf.stop(); 
+      pf.stop();
     }
   }
 };
@@ -28,15 +28,15 @@ std::chrono::microseconds parallel_pipeline_taskflow_1_pipe(
   unsigned num_lines, unsigned num_threads, size_t size) {
 
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
     tf::Pipe{tf::PipeType::SERIAL, Input{0, size}}
-  ); 
+  );
 
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
 
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
@@ -45,20 +45,20 @@ std::chrono::microseconds parallel_pipeline_taskflow_1_pipe(
 // parallel_pipeline_taskflow_2_pipes
 std::chrono::microseconds parallel_pipeline_taskflow_2_pipes(
   std::string pipes, unsigned num_lines, unsigned num_threads, size_t size) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   std::vector<std::array<int, 2>> mybuffer(num_lines);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
     tf::Pipe{tf::PipeType::SERIAL, Input{0, size}},
-    tf::Pipe{to_pipe_type(pipes[1]), Filter{}} 
-  ); 
-  
+    tf::Pipe{to_pipe_type(pipes[1]), Filter{}}
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -66,9 +66,9 @@ std::chrono::microseconds parallel_pipeline_taskflow_2_pipes(
 // parallel_pipeline_taskflow_3_pipes
 std::chrono::microseconds parallel_pipeline_taskflow_3_pipes(
   std::string pipes, unsigned num_lines, unsigned num_threads, size_t size) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   std::vector<std::array<int, 3>> mybuffer(num_lines);
 
@@ -77,10 +77,10 @@ std::chrono::microseconds parallel_pipeline_taskflow_3_pipes(
     tf::Pipe{tf::PipeType::SERIAL, Input{0, size}},
     tf::Pipe{to_pipe_type(pipes[1]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[2]), Filter{}}
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -88,9 +88,9 @@ std::chrono::microseconds parallel_pipeline_taskflow_3_pipes(
 // parallel_pipeline_taskflow_4_pipes
 std::chrono::microseconds parallel_pipeline_taskflow_4_pipes(
   std::string pipes, unsigned num_lines, unsigned num_threads, size_t size) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   std::vector<std::array<int, 4>> mybuffer(num_lines);
 
@@ -100,10 +100,10 @@ std::chrono::microseconds parallel_pipeline_taskflow_4_pipes(
     tf::Pipe{to_pipe_type(pipes[1]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[2]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[3]), Filter{}}
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -111,9 +111,9 @@ std::chrono::microseconds parallel_pipeline_taskflow_4_pipes(
 // parallel_pipeline_taskflow_5_pipes
 std::chrono::microseconds parallel_pipeline_taskflow_5_pipes(
   std::string pipes, unsigned num_lines, unsigned num_threads, size_t size) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
@@ -122,10 +122,10 @@ std::chrono::microseconds parallel_pipeline_taskflow_5_pipes(
     tf::Pipe{to_pipe_type(pipes[2]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[3]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[4]), Filter{}}
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -135,7 +135,7 @@ std::chrono::microseconds parallel_pipeline_taskflow_6_pipes(
   std::string pipes, unsigned num_lines, unsigned num_threads, size_t size) {
 
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
@@ -143,12 +143,12 @@ std::chrono::microseconds parallel_pipeline_taskflow_6_pipes(
     tf::Pipe{to_pipe_type(pipes[1]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[2]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[3]), Filter{}},
-    tf::Pipe{to_pipe_type(pipes[4]), Filter{}}, 
+    tf::Pipe{to_pipe_type(pipes[4]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[5]), Filter{}}
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -158,7 +158,7 @@ std::chrono::microseconds parallel_pipeline_taskflow_7_pipes(
   std::string pipes, unsigned num_lines, unsigned num_threads, size_t size) {
 
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   std::vector<std::array<int, 7>> mybuffer(num_lines);
 
@@ -168,13 +168,13 @@ std::chrono::microseconds parallel_pipeline_taskflow_7_pipes(
     tf::Pipe{to_pipe_type(pipes[1]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[2]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[3]), Filter{}},
-    tf::Pipe{to_pipe_type(pipes[4]), Filter{}}, 
+    tf::Pipe{to_pipe_type(pipes[4]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[5]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[6]), Filter{}}
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -182,9 +182,9 @@ std::chrono::microseconds parallel_pipeline_taskflow_7_pipes(
 // parallel_pipeline_taskflow_8_pipes
 std::chrono::microseconds parallel_pipeline_taskflow_8_pipes(
   std::string pipes, unsigned num_lines, unsigned num_threads, size_t size) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
@@ -192,14 +192,14 @@ std::chrono::microseconds parallel_pipeline_taskflow_8_pipes(
     tf::Pipe{to_pipe_type(pipes[1]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[2]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[3]), Filter{}},
-    tf::Pipe{to_pipe_type(pipes[4]), Filter{}}, 
+    tf::Pipe{to_pipe_type(pipes[4]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[5]), Filter{}},
-    tf::Pipe{to_pipe_type(pipes[6]), Filter{}}, 
+    tf::Pipe{to_pipe_type(pipes[6]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[7]), Filter{}}
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -207,9 +207,9 @@ std::chrono::microseconds parallel_pipeline_taskflow_8_pipes(
 // parallel_pipeline_taskflow_9_pipes
 std::chrono::microseconds parallel_pipeline_taskflow_9_pipes(
   std::string pipes, unsigned num_lines, unsigned num_threads, size_t size) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
@@ -217,15 +217,15 @@ std::chrono::microseconds parallel_pipeline_taskflow_9_pipes(
     tf::Pipe{to_pipe_type(pipes[1]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[2]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[3]), Filter{}},
-    tf::Pipe{to_pipe_type(pipes[4]), Filter{}}, 
+    tf::Pipe{to_pipe_type(pipes[4]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[5]), Filter{}},
-    tf::Pipe{to_pipe_type(pipes[6]), Filter{}}, 
-    tf::Pipe{to_pipe_type(pipes[7]), Filter{}}, 
+    tf::Pipe{to_pipe_type(pipes[6]), Filter{}},
+    tf::Pipe{to_pipe_type(pipes[7]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[8]), Filter{}}
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -233,9 +233,9 @@ std::chrono::microseconds parallel_pipeline_taskflow_9_pipes(
 // parallel_pipeline_taskflow_10_pipes
 std::chrono::microseconds parallel_pipeline_taskflow_10_pipes(
   std::string pipes, unsigned num_lines, unsigned num_threads, size_t size) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
@@ -243,16 +243,16 @@ std::chrono::microseconds parallel_pipeline_taskflow_10_pipes(
     tf::Pipe{to_pipe_type(pipes[1]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[2]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[3]), Filter{}},
-    tf::Pipe{to_pipe_type(pipes[4]), Filter{}}, 
+    tf::Pipe{to_pipe_type(pipes[4]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[5]), Filter{}},
-    tf::Pipe{to_pipe_type(pipes[6]), Filter{}}, 
-    tf::Pipe{to_pipe_type(pipes[7]), Filter{}}, 
+    tf::Pipe{to_pipe_type(pipes[6]), Filter{}},
+    tf::Pipe{to_pipe_type(pipes[7]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[8]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[9]), Filter{}}
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -261,9 +261,9 @@ std::chrono::microseconds parallel_pipeline_taskflow_10_pipes(
 // parallel_pipeline_taskflow_11_pipes
 std::chrono::microseconds parallel_pipeline_taskflow_11_pipes(
   std::string pipes, unsigned num_lines, unsigned num_threads, size_t size) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
@@ -271,17 +271,17 @@ std::chrono::microseconds parallel_pipeline_taskflow_11_pipes(
     tf::Pipe{to_pipe_type(pipes[1]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[2]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[3]), Filter{}},
-    tf::Pipe{to_pipe_type(pipes[4]), Filter{}}, 
+    tf::Pipe{to_pipe_type(pipes[4]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[5]), Filter{}},
-    tf::Pipe{to_pipe_type(pipes[6]), Filter{}}, 
-    tf::Pipe{to_pipe_type(pipes[7]), Filter{}}, 
+    tf::Pipe{to_pipe_type(pipes[6]), Filter{}},
+    tf::Pipe{to_pipe_type(pipes[7]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[8]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[9]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[10]), Filter{}}
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -289,9 +289,9 @@ std::chrono::microseconds parallel_pipeline_taskflow_11_pipes(
 // parallel_pipeline_taskflow_12_pipes
 std::chrono::microseconds parallel_pipeline_taskflow_12_pipes(
   std::string pipes, unsigned num_lines, unsigned num_threads, size_t size) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
@@ -299,18 +299,18 @@ std::chrono::microseconds parallel_pipeline_taskflow_12_pipes(
     tf::Pipe{to_pipe_type(pipes[1]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[2]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[3]), Filter{}},
-    tf::Pipe{to_pipe_type(pipes[4]), Filter{}}, 
+    tf::Pipe{to_pipe_type(pipes[4]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[5]), Filter{}},
-    tf::Pipe{to_pipe_type(pipes[6]), Filter{}}, 
-    tf::Pipe{to_pipe_type(pipes[7]), Filter{}}, 
+    tf::Pipe{to_pipe_type(pipes[6]), Filter{}},
+    tf::Pipe{to_pipe_type(pipes[7]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[8]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[9]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[10]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[11]), Filter{}}
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -318,9 +318,9 @@ std::chrono::microseconds parallel_pipeline_taskflow_12_pipes(
 // parallel_pipeline_taskflow_13_pipes
 std::chrono::microseconds parallel_pipeline_taskflow_13_pipes(
   std::string pipes, unsigned num_lines, unsigned num_threads, size_t size) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
@@ -328,19 +328,19 @@ std::chrono::microseconds parallel_pipeline_taskflow_13_pipes(
     tf::Pipe{to_pipe_type(pipes[1]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[2]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[3]), Filter{}},
-    tf::Pipe{to_pipe_type(pipes[4]), Filter{}}, 
+    tf::Pipe{to_pipe_type(pipes[4]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[5]), Filter{}},
-    tf::Pipe{to_pipe_type(pipes[6]), Filter{}}, 
-    tf::Pipe{to_pipe_type(pipes[7]), Filter{}}, 
+    tf::Pipe{to_pipe_type(pipes[6]), Filter{}},
+    tf::Pipe{to_pipe_type(pipes[7]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[8]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[9]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[10]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[11]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[12]), Filter{}}
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -348,9 +348,9 @@ std::chrono::microseconds parallel_pipeline_taskflow_13_pipes(
 // parallel_pipeline_taskflow_14_pipes
 std::chrono::microseconds parallel_pipeline_taskflow_14_pipes(
   std::string pipes, unsigned num_lines, unsigned num_threads, size_t size) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
@@ -358,20 +358,20 @@ std::chrono::microseconds parallel_pipeline_taskflow_14_pipes(
     tf::Pipe{to_pipe_type(pipes[1]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[2]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[3]), Filter{}},
-    tf::Pipe{to_pipe_type(pipes[4]), Filter{}}, 
+    tf::Pipe{to_pipe_type(pipes[4]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[5]), Filter{}},
-    tf::Pipe{to_pipe_type(pipes[6]), Filter{}}, 
-    tf::Pipe{to_pipe_type(pipes[7]), Filter{}}, 
+    tf::Pipe{to_pipe_type(pipes[6]), Filter{}},
+    tf::Pipe{to_pipe_type(pipes[7]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[8]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[9]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[10]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[11]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[12]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[13]), Filter{}}
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -379,9 +379,9 @@ std::chrono::microseconds parallel_pipeline_taskflow_14_pipes(
 // parallel_pipeline_taskflow_15_pipes
 std::chrono::microseconds parallel_pipeline_taskflow_15_pipes(
   std::string pipes, unsigned num_lines, unsigned num_threads, size_t size) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
@@ -389,10 +389,10 @@ std::chrono::microseconds parallel_pipeline_taskflow_15_pipes(
     tf::Pipe{to_pipe_type(pipes[1]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[2]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[3]), Filter{}},
-    tf::Pipe{to_pipe_type(pipes[4]), Filter{}}, 
+    tf::Pipe{to_pipe_type(pipes[4]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[5]), Filter{}},
-    tf::Pipe{to_pipe_type(pipes[6]), Filter{}}, 
-    tf::Pipe{to_pipe_type(pipes[7]), Filter{}}, 
+    tf::Pipe{to_pipe_type(pipes[6]), Filter{}},
+    tf::Pipe{to_pipe_type(pipes[7]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[8]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[9]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[10]), Filter{}},
@@ -400,10 +400,10 @@ std::chrono::microseconds parallel_pipeline_taskflow_15_pipes(
     tf::Pipe{to_pipe_type(pipes[12]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[13]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[14]), Filter{}}
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
@@ -411,9 +411,9 @@ std::chrono::microseconds parallel_pipeline_taskflow_15_pipes(
 // parallel_pipeline_taskflow_16_pipes
 std::chrono::microseconds parallel_pipeline_taskflow_16_pipes(
   std::string pipes, unsigned num_lines, unsigned num_threads, size_t size) {
-  
+
   tf::Taskflow taskflow;
-  tf::Executor executor(num_threads);
+  static tf::Executor executor(num_threads);
 
   auto beg = std::chrono::high_resolution_clock::now();
   tf::Pipeline pl(num_lines,
@@ -421,10 +421,10 @@ std::chrono::microseconds parallel_pipeline_taskflow_16_pipes(
     tf::Pipe{to_pipe_type(pipes[1]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[2]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[3]), Filter{}},
-    tf::Pipe{to_pipe_type(pipes[4]), Filter{}}, 
+    tf::Pipe{to_pipe_type(pipes[4]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[5]), Filter{}},
-    tf::Pipe{to_pipe_type(pipes[6]), Filter{}}, 
-    tf::Pipe{to_pipe_type(pipes[7]), Filter{}}, 
+    tf::Pipe{to_pipe_type(pipes[6]), Filter{}},
+    tf::Pipe{to_pipe_type(pipes[7]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[8]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[9]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[10]), Filter{}},
@@ -433,24 +433,24 @@ std::chrono::microseconds parallel_pipeline_taskflow_16_pipes(
     tf::Pipe{to_pipe_type(pipes[13]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[14]), Filter{}},
     tf::Pipe{to_pipe_type(pipes[15]), Filter{}}
-  ); 
-  
+  );
+
   taskflow.composed_of(pl);
-  executor.run(taskflow).wait(); 
+  executor.run(taskflow).wait();
   auto end = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::microseconds>(end - beg);
 }
 
 std::chrono::microseconds measure_time_taskflow(
   std::string pipes, unsigned num_lines, unsigned num_threads, size_t size) {
- 
-  std::chrono::microseconds elapsed; 
+
+  std::chrono::microseconds elapsed;
 
   switch(pipes.size()) {
     case 1:
       elapsed = parallel_pipeline_taskflow_1_pipe(num_lines, num_threads, size);
       break;
-    
+
     case 2:
       elapsed = parallel_pipeline_taskflow_2_pipes(pipes, num_lines, num_threads, size);
       break;
@@ -458,7 +458,7 @@ std::chrono::microseconds measure_time_taskflow(
     case 3:
       elapsed = parallel_pipeline_taskflow_3_pipes(pipes, num_lines, num_threads, size);
       break;
-    
+
     case 4:
       elapsed = parallel_pipeline_taskflow_4_pipes(pipes, num_lines, num_threads, size);
       break;
@@ -466,11 +466,11 @@ std::chrono::microseconds measure_time_taskflow(
     case 5:
       elapsed = parallel_pipeline_taskflow_5_pipes(pipes, num_lines, num_threads, size);
       break;
-    
+
     case 6:
       elapsed = parallel_pipeline_taskflow_6_pipes(pipes, num_lines, num_threads, size);
       break;
-    
+
     case 7:
       elapsed = parallel_pipeline_taskflow_7_pipes(pipes, num_lines, num_threads, size);
       break;
@@ -478,7 +478,7 @@ std::chrono::microseconds measure_time_taskflow(
     case 8:
       elapsed = parallel_pipeline_taskflow_8_pipes(pipes, num_lines, num_threads, size);
       break;
-    
+
     case 9:
       elapsed = parallel_pipeline_taskflow_9_pipes(pipes, num_lines, num_threads, size);
       break;
@@ -486,11 +486,11 @@ std::chrono::microseconds measure_time_taskflow(
     case 10:
       elapsed = parallel_pipeline_taskflow_10_pipes(pipes, num_lines, num_threads, size);
       break;
-    
+
     case 11:
       elapsed = parallel_pipeline_taskflow_11_pipes(pipes, num_lines, num_threads, size);
       break;
-    
+
     case 12:
       elapsed = parallel_pipeline_taskflow_12_pipes(pipes, num_lines, num_threads, size);
       break;
@@ -498,7 +498,7 @@ std::chrono::microseconds measure_time_taskflow(
     case 13:
       elapsed = parallel_pipeline_taskflow_13_pipes(pipes, num_lines, num_threads, size);
       break;
-    
+
     case 14:
       elapsed = parallel_pipeline_taskflow_14_pipes(pipes, num_lines, num_threads, size);
       break;
@@ -506,10 +506,14 @@ std::chrono::microseconds measure_time_taskflow(
     case 15:
       elapsed = parallel_pipeline_taskflow_15_pipes(pipes, num_lines, num_threads, size);
       break;
-    
+
     case 16:
       elapsed = parallel_pipeline_taskflow_16_pipes(pipes, num_lines, num_threads, size);
       break;
+
+    default:
+      throw std::runtime_error("can support only up to 16 pipes");
+    break;
   }
 
   //std::ofstream outputfile;
