@@ -1,10 +1,12 @@
 #include "matrix_multiplication.hpp"
-#include <taskflow/taskflow.hpp> 
+#include <taskflow/taskflow.hpp>
+#include <taskflow/algorithm/for_each.hpp>
 
 // matrix_multiplication_taskflow
 void matrix_multiplication_taskflow(unsigned num_threads) {
 
-  tf::Executor executor(num_threads); 
+  static tf::Executor executor(num_threads);
+
   tf::Taskflow taskflow;
 
   auto init_a = taskflow.for_each_index(0, N, 1, [&] (int i) {
@@ -12,7 +14,7 @@ void matrix_multiplication_taskflow(unsigned num_threads) {
       a[i][j] = i + j;
     }
   });
-  
+
   auto init_b = taskflow.for_each_index(0, N, 1, [&] (int i) {
     for(int j=0; j<N; ++j) {
       b[i][j] = i * j;
@@ -36,45 +38,8 @@ void matrix_multiplication_taskflow(unsigned num_threads) {
 
   comp_c.succeed(init_a, init_b, init_c);
 
-  /*auto sync = taskflow.emplace([](){});
+  executor.run(taskflow).get();
 
-  for(int i=0; i<N; ++i) {
-    taskflow.emplace([&, i=i](){
-      for(int j=0; j<N; ++j) {
-        a[i][j] = i + j;
-      }
-    }).precede(sync);
-  }
-
-  for(int i=0; i<N; ++i) {
-    taskflow.emplace([&, i=i](){
-      for(int j=0; j<N; ++j) {
-        b[i][j] = i * j;
-      }
-    }).precede(sync);
-  }
-
-  for(int i=0; i<N; ++i) {
-    taskflow.emplace([&, i=i](){
-      for(int j=0; j<N; ++j) {
-        c[i][j] = 0;;
-      }
-    }).precede(sync);
-  }
-
-  for(int i=0; i<N; ++i) {
-    auto t = taskflow.emplace([&, i=i](){
-      for(int j=0; j<N; ++j) {
-        for(int k=0; k<N; k++) {
-          c[i][j] += a[i][k] * b[k][j];
-        }
-      }
-    });
-    sync.precede(t);
-  }*/
-
-  executor.run(taskflow).get(); 
-  
   //std::cout << reduce_sum() << std::endl;
   //taskflow.dump(std::cout);
 }
